%define nspr_version 4.13.0
Name        : nss
Version     : 3.30
Release: 6
Group       : System Environment/Libraries
License     : MPL-2.0
URL         : https://developer.mozilla.org/en-US/docs/Mozilla/Projects/NSS
Summary     : Network Security Services
Requires    : nspr >= %{nspr_version}

BuildRequires: sqlite3-devel
BuildRequires: nspr-devel

Source0: https://ftp.mozilla.org/pub/mozilla.org/security/nss/releases/NSS_3_30_RTM/src/nss-%{version}.tar.gz

Patch0: nss-pase.patch
Patch1: nss-vfyutil-uninitialized-variable.patch

%description
Network Security Services (NSS) is a set of libraries designed to
support cross-platform development of security-enabled client and
server applications. Applications built with NSS can support SSL v2
and v3, TLS, PKCS #5, PKCS #7, PKCS #11, PKCS #12, S/MIME, X.509
v3 certificates, and other security standards.

%package devel
Summary: Network Security Services Development files
Requires: %{name} = %{version}

%description devel
Network Security Services (NSS) is a set of libraries designed to
support cross-platform development of security-enabled client and
server applications. Applications built with NSS can support SSL v2
and v3, TLS, PKCS #5, PKCS #7, PKCS #11, PKCS #12, S/MIME, X.509
v3 certificates, and other security standards.

%prep

%setup -q

%patch0 -p1
%patch1 -p1

%build

cd nss

cat <<EOF > _make
#!/bin/sh

export CC=gcc
export CXX=g++
export NS_USE_GCC=1
export NSS_USE_SYSTEM_SQLITE=1
export NSS_DISABLE_GTESTS=1
export NSPR_INCLUDE_DIR=$(nspr-config --includedir)
export NSPR_LIB_DIR=$(nspr-config --libdir)
export BUILD_OPT=1
export OPT_FLAGS='-DNO_VIZ -I/QOpenSys/pkgs/include'

%ifarch ppc64
export USE_64=1
%endif

make "\$@"
EOF

chmod +x _make

./_make nss_build_all
    
%install

cd nss

mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_libdir}
mkdir -p %{buildroot}%{_libdir}/pkgconfig
mkdir -p %{buildroot}%{_includedir}/nss3

cp -L ../dist/OS400*/lib/*.so %{buildroot}%{_libdir}
cp -L ../dist/OS400*/bin/* %{buildroot}%{_bindir}
cp -L ../dist/public/nss/*.h %{buildroot}%{_includedir}/nss3


MAJOR=`grep "#define.*NSS_VMAJOR" < lib/nss/nss.h | awk '{print $3}'`
MINOR=`grep "#define.*NSS_VMINOR" < lib/nss/nss.h | awk '{print $3}'`
PATCH=`grep "#define.*NSS_VPATCH" < lib/nss/nss.h | awk '{print $3}'`

sed \
  -e 's|@prefix@|%{_prefix}|' \
  -e "s|@MOD_MAJOR_VERSION@|$MAJOR|" \
  -e "s|@MOD_MINOR_VERSION@|$MINOR|" \
  -e "s|@MOD_PATCH_VERSION@|$PATCH|" \
  -e 's|-Wl,-rpath-link,$libdir ||' \
  pkg/pkg-config/nss-config.in > %{buildroot}%{_bindir}/nss-config

chmod +x %{buildroot}%{_bindir}/nss-config

cat <<EOF > %{buildroot}%{_libdir}/pkgconfig/nss.pc
prefix=%{_prefix}
exec_prefix=\${prefix}
libdir=%{_libdir}
includedir=\${prefix}/include/nss3

Name: NSS
Description: Network Security Services
Version: %{version}
Requires: nspr >= %{nspr_version}
Libs: -lssl3 -lsmime3 -lnss3 -lnssutil3
Cflags: -I\${includedir}
EOF

%files
%defattr(-, qsys, *none)

%{_libdir}/libfreebl3.so
%{_libdir}/libnss3.so
%{_libdir}/libnssckbi.so
%{_libdir}/libnssdbm3.so
%{_libdir}/libnssutil3.so
%{_libdir}/libsmime3.so 
%{_libdir}/libsoftokn3.so
%{_libdir}/libssl3.so

%{_bindir}/addbuiltin
%{_bindir}/atob
%{_bindir}/baddbdir
%{_bindir}/bltest
%{_bindir}/btoa
%{_bindir}/certcgi
%{_bindir}/certutil
%{_bindir}/chktest
%{_bindir}/cmsutil
%{_bindir}/conflict
%{_bindir}/crlutil
%{_bindir}/crmftest
%{_bindir}/dbtest
%{_bindir}/derdump
%{_bindir}/dertimetest
%{_bindir}/digest
%{_bindir}/ecperf
%{_bindir}/encodeinttest
%{_bindir}/example
%{_bindir}/fbectest
%{_bindir}/fipstest
%{_bindir}/httpserv
%{_bindir}/listsuites
%{_bindir}/makepqg
%{_bindir}/mangle
%{_bindir}/minigzip
%{_bindir}/modutil
%{_bindir}/multinit
%{_bindir}/nonspr10
%{_bindir}/ocspclnt
%{_bindir}/ocspresp
%{_bindir}/oidcalc
%{_bindir}/p7content
%{_bindir}/p7env
%{_bindir}/p7sign
%{_bindir}/p7verify
%{_bindir}/pk11ectest
%{_bindir}/pk11gcmtest
%{_bindir}/pk11mode
%{_bindir}/pk12util
%{_bindir}/pk1sign
%{_bindir}/pkix-errcodes
%{_bindir}/pp
%{_bindir}/pwdecrypt
%{_bindir}/remtest
%{_bindir}/rsaperf
%{_bindir}/sdrtest
%{_bindir}/secmodtest
%{_bindir}/selfserv
%{_bindir}/shlibsign
%{_bindir}/signtool
%{_bindir}/signver
%{_bindir}/ssltap
%{_bindir}/strsclnt
%{_bindir}/symkeyutil
%{_bindir}/tstclnt
%{_bindir}/vfychain
%{_bindir}/vfyserv


%files devel
%defattr(-, qsys, *none)

%{_bindir}/nss-config

%{_libdir}/pkgconfig/nss.pc

%{_includedir}/*

%changelog
* Wed Nov 27 2019 Kevin Adler <kadler@us.ibm.com> - 3.30
- Use SPDX license identifier
- Update URL

* Tue Mar 13 2018 - Kevin Adler <kadler@us.ibm.com>
- Add more unpackaged binaries

* Tue Mar 13 2018 - Kevin Adler <kadler@us.ibm.com>
- Missing BuildRequires of gawk, use PASE awk instead

* Mon Mar 12 2018 - Kevin Adler <kadler@us.ibm.com>
- Add unshipped files

* Sat Mar 03 2018 - Kevin Adler <kadler@us.ibm.com>
- Add missing BuildRequires
- Let automatic dependency generation pick up sqlite3

* Wed Dec 20 2017 - Kevin Adler <kadler@us.ibm.com>
- Remove 64-bit GCC script workarounds
- OBJECT_MODE now always set by build and install macros

* Tue Nov 07 2017 - Kevin Adler <kadler@us.ibm.com>
- Fix license

* Fri Sep 15 2017 - Kevin Adler <kadler@us.ibm.com>
- NSS requires sqlite3 library

* Fri Sep 15 2017 - Kevin Adler <kadler@us.ibm.com>
- Fix 64-bit build

* Thu Aug 24 2017 - Kevin Adler <kadler@us.ibm.com>
- Acutally build nspr on IBM i

* Mon Jun 05 2017 - Kevin Adler <kadler@us.ibm.com>
- Use make_build and make_install macros

* Sun Apr 23 2017 - Kevin Adler <kadler@us.ibm.com>
- Remove extra space in Summary lines

* Thu Apr 20 2017 - Kevin Adler <kadler@us.ibm.com>
- Initial package, repackaging AIX rpm
